pub struct LabelWithWidgets {
child: Label,
widgets: RefCell<Vec<Widget>>,
widgets_sizes: RefCell<Vec<(i32, i32)>>,
label: RefCell<Option<String>>,
use_markup: PhantomData<bool>,
ellipsize: Cell<bool>,
justify: PhantomData<Justification>,
}Fields
child: LabelThe child GtkLabel.
widgets: RefCell<Vec<Widget>>The widgets to display in the label.
widgets_sizes: RefCell<Vec<(i32, i32)>>label: RefCell<Option<String>>The text of the label.
use_markup: PhantomData<bool>Whether the label includes Pango markup.
ellipsize: Cell<bool>Whether the label should be ellipsized.
justify: PhantomData<Justification>The alignment of the lines in the text of the label, relative to each other.
Implementations
Sourceimpl LabelWithWidgets
impl LabelWithWidgets
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl LabelWithWidgets
impl LabelWithWidgets
Sourcepub(super) fn set_label_and_widgets<P: IsA<Widget>>(
&self,
label: String,
widgets: Vec<P>,
)
pub(super) fn set_label_and_widgets<P: IsA<Widget>>( &self, label: String, widgets: Vec<P>, )
Set the label and widgets to display.
Sourcefn set_widgets<P: IsA<Widget>>(&self, widgets: Vec<P>)
fn set_widgets<P: IsA<Widget>>(&self, widgets: Vec<P>)
Set the widgets to display.
Sourcefn uses_markup(&self) -> bool
fn uses_markup(&self) -> bool
Whether the label includes Pango markup.
Sourcefn set_use_markup(&self, use_markup: bool)
fn set_use_markup(&self, use_markup: bool)
Set whether the label includes Pango markup.
Sourcefn set_ellipsize(&self, ellipsize: bool)
fn set_ellipsize(&self, ellipsize: bool)
Sets whether the text of the label should be ellipsized.
Sourcefn justify(&self) -> Justification
fn justify(&self) -> Justification
The alignment of the lines in the text of the label, relative to each other.
Sourcefn set_justify(&self, justify: Justification)
fn set_justify(&self, justify: Justification)
Set the alignment of the lines in the text of the label, relative to each other.
Sourcefn invalidate_widgets(&self)
fn invalidate_widgets(&self)
Re-compute the child widgets allocations in the Pango layout.
Sourcefn allocate_shapes(&self)
fn allocate_shapes(&self)
Allocate shapes in the Pango layout for the child widgets.
Sourcefn allocate_widgets(&self)
fn allocate_widgets(&self)
Allocate the child widgets.